<template>
    <div class="w-100">
        <card_form :cardData="card_form" :cardView="cardView" :cards="cards"> </card_form>
        <v-card v-if="!loading">
            <v-card-title>
                <v-layout>
                    <v-flex justify-space-between align-center>
                        <h2>My Cards</h2>
                        <v-btn color="primary" @click="addCard" >Add Card</v-btn>
                    </v-flex>
                </v-layout>
            </v-card-title>
            <v-divider></v-divider>
            <v-card-text>
                <v-layout row wrap mb-0 v-if="cards.length">
                    <v-flex md4 sm6 xs12 v-for="card in cards" :key="card.id" justify-center>
                        <v-flex class="_cards_detail" align-center justify-center>
                            <div class="card_icon" v-if="card.brand == 'Visa'">
                                <img :src="$store.state.domain + 'img/card_logo/Visa.svg'">
                            </div>
                            <div class="card_icon" v-else-if="card.brand == 'MasterCard'">
                                <img :src="$store.state.domain + 'img/card_logo/Mastercard.svg'">
                            </div>
                            <div class="card_icon" v-else-if="card.brand == 'American Express'">
                                <img :src="$store.state.domain + 'img/card_logo/American_Express.svg'">
                            </div>
                            <div class="card_icon" v-else-if="card.brand == 'JCB'">
                                <img :src="$store.state.domain + 'img/card_logo/JCB.svg'">
                            </div>
                            <div class="card_icon" v-else-if="card.brand == 'Discover'">
                                <img :src="$store.state.domain + 'img/card_logo/Discover_Card.svg'">
                            </div>
                            <div class="card_icon" v-else>
                                <v-icon>credit_card</v-icon>
                            </div>
                            <div class="card_name mb-2">
                                <h3>{{ card.name }}</h3>
                            </div>
                            <div class="card_details">
                                <div class="card_number mb-2">
                                    <h3>XXXX-XXXX-XXXX-{{ card.last4 }}</h3>
                                </div>
                            </div>
                            <v-btn
                                color="primary"
                                outline
                                @click="cardDelete(card.id)"
                                class="m-0">
                                <v-icon left dark color="primary">delete</v-icon>
                                Delete Card
                            </v-btn>
                        </v-flex>
                    </v-flex>
                </v-layout>
                <v-layout v-else>
                    <v-alert :value="true" type="error" outline class="w-100">
                        There is no credit card listed yet
                    </v-alert>
                </v-layout>
            </v-card-text>
        </v-card>
        <v-card v-else class="w-100 _progress">
            <v-progress-circular
                :width="2"
                :size="50"
                color="#525252"
                indeterminate
            ></v-progress-circular>
            <span>Loading cards</span>
        </v-card>
    </div>
</template>
<script>
import axios from 'axios';
import Vue from 'vue';
import CardForm from '~/components/cardForm.vue';

Vue.component('card_form', CardForm);

export default {
    layout: 'customer',
    data() {
        return {
            cardView: this,
            cards : [],
            loading: true,
            card_form: false,
        }
    },
    methods: {
        getCards: function() {
            if (this.$store.state.cards.length) {
                this.cards = this.$store.state.cards;
                this.loading = false;
            } else {
                axios.get(this.$store.state.api_domain + '?comp=process&action=getCards', {withCredentials: true})
                .then((res) => {
                    if (res.data.status == 'success') {
                        this.cards = res.data.message.data;
                        this.$store.commit('setCards', res.data.message.data);
                    }
                    if (res.data.status == 'error') {
                        this.$store.commit('showSnackBar', res.data.message);
                    }
                    this.loading = false;
                });
            }
        },
        cardDelete: function(id_card) {
            this.$store.commit('showSnackBar', 'Please Wait your card is deleting..');
            var form_data = new FormData();
            form_data.append('id_card', id_card);
            axios.post(this.$store.state.api_domain + '?comp=process&action=deleteCard', form_data,{withCredentials: true})
            .then((res) => {
                this.$store.commit('hideSnackBar');
                if (res.data.status == 'success') {
                    this.loading = true;
                    this.$store.commit('setCards', '');
                    this.getCards();
                    this.$store.commit('showSnackBar', res.data.message);
                }
                if (res.data.status == 'error') {
                    this.$store.commit('showSnackBar', res.data.message);
                }
            });
        },
        addCard: function() {
            this.loading = true;
            this.card_form = true;
        }
    },
    created() {
        this.getCards();
    },
    head () {
      return {
        title: 'Cards | Account | Balingwiredirect.com',
        meta: [
          { hid: 'description', name: 'description', content: 'All cards' },
          { hid: 'keywords', name: 'keywords',  content: 'cards' }
        ]
      }
    }
}
</script>